function q = rotquat(theta,rot_axis)
%  Compute a quaternion from an angle and a rotation axis
%  
%  $BEGIN
%  $HEADER rotquat
%
%  Compute a quaternion from an angle and a rotation axis
%
%  $HEADER REFERENCE
%  W. Bean, Operational Use of Quaternions
%  in the Description of Rigid Body Motion,
%  MSC Internal Note #69-FM-237, (1969)
%
%  $HEADER PROGRAMMER
%  John W. Craft, Jr.
%  University of Houston, (2005)
%
%  $HEADER VERSION
%  1.0.0
%
%  Example
%  my_quaternion = rotquat(rotation_theta, rotation_axis)
%
%  See Also quatmat quatrot quatmult
%  
%  $END
%

s = cos(theta/2.0);
v = rot_axis .* sin(theta/2.0);
q = [s v];

return

